﻿''' <summary>
''' A "Return Packet" that contains all of the information
''' required by the GUI
''' </summary>
''' <remarks></remarks>
Public Class DisplayPacket
    Private Const MIN_SLEEP As Integer = 0
    Private Const MAX_SLEEP As Integer = 5000

    Private pfvDisplayText As String
    Private pAlternateText As String
    Private pfvF_Annunciator As Boolean
    Private pfvG_Annunciator As Boolean
    Private pfvCarry_Annunciator As Boolean
    Private pfvOverflow_Annunciator As Boolean
    Private pfvPrgm_Annunciator As Boolean
    Private pfvDelay As Integer
    Private pfvMenuNeedsUpdating As Boolean
    Private pfvBeep As Boolean
    Private pfvStart As StartType

    ''' <summary>
    ''' Which type of program are we starting
    ''' </summary>
    ''' <remarks></remarks>
    Public Enum StartType As Integer
        None
        RunProgram
        RunLine
    End Enum

    ''' <summary>
    ''' Default constructor
    ''' </summary>
    ''' <remarks></remarks>
    Public Sub New()
        pfvDisplayText = String.Empty
        pAlternateText = String.Empty
        pfvF_Annunciator = False
        pfvG_Annunciator = False
        pfvCarry_Annunciator = False
        pfvOverflow_Annunciator = False
        pfvPrgm_Annunciator = False
        pfvDelay = 0
        pfvMenuNeedsUpdating = False
        pfvBeep = False
        pfvStart = StartType.None
    End Sub

    ''' <summary>
    ''' The main text for the display
    ''' </summary>
    ''' <value>The new main text</value>
    ''' <returns>The current text</returns>
    ''' <remarks></remarks>
    Public Property DisplayText As String
        Get
            Return pfvDisplayText
        End Get
        Set(value As String)
            If Not IsNothing(value) Then
                pfvDisplayText = value
            End If
        End Set
    End Property

    ''' <summary>
    ''' The alternate text for the display (typically an error message or pause)
    ''' </summary>
    ''' <value>The new alternate text</value>
    ''' <returns>The current alternate text</returns>
    ''' <remarks></remarks>
    Public Property AlternateText As String
        Get
            Return pAlternateText
        End Get
        Set(value As String)
            If Not IsNothing(value) Then
                pAlternateText = value
            End If
        End Set
    End Property

    ''' <summary>
    ''' Should the F Annunciator be "lit"
    ''' </summary>
    ''' <value>The new F Annunciator value</value>
    ''' <returns>The current F Annunciator value</returns>
    ''' <remarks>Corresponds to the blue F_Key</remarks>
    Public Property F_Annunciator As Boolean
        Get
            Return pfvF_Annunciator
        End Get
        Set(value As Boolean)
            pfvF_Annunciator = value
        End Set
    End Property

    ''' <summary>
    ''' Should the G Annunciator be "lit"
    ''' </summary>
    ''' <value>The new G Annunciator value</value>
    ''' <returns>The current G Annunciator value</returns>
    ''' <remarks>Corresponds to the yellow G_Key</remarks>
    Public Property G_Annunciator As Boolean
        Get
            Return pfvG_Annunciator
        End Get
        Set(value As Boolean)
            pfvG_Annunciator = value
        End Set
    End Property

    ''' <summary>
    ''' Should the Carry Annunciator be "lit"
    ''' </summary>
    ''' <value>The new Carry Annunciator value</value>
    ''' <returns>The current Carry Annunciator value</returns>
    ''' <remarks></remarks>
    Public Property Carry_Annunciator As Boolean
        Get
            Return pfvCarry_Annunciator
        End Get
        Set(value As Boolean)
            pfvCarry_Annunciator = value
        End Set
    End Property

    ''' <summary>
    ''' Should the Overflow Annunciator be "lit"
    ''' </summary>
    ''' <value>The new Overflow Annunciator value</value>
    ''' <returns>The current Overflow Annunciator value</returns>
    ''' <remarks></remarks>
    Public Property Overflow_Annunciator As Boolean
        Get
            Return pfvOverflow_Annunciator
        End Get
        Set(value As Boolean)
            pfvOverflow_Annunciator = value
        End Set
    End Property

    ''' <summary>
    ''' Should the Program Annunciator be "lit"
    ''' </summary>
    ''' <value>The new Program Annunciator value</value>
    ''' <returns>The current Program Annunciator value</returns>
    ''' <remarks></remarks>
    Public Property Prgm_Annunciator As Boolean
        Get
            Return pfvPrgm_Annunciator
        End Get
        Set(value As Boolean)
            pfvPrgm_Annunciator = value
        End Set
    End Property

    ''' <summary>
    ''' The delay (in miliseconds) for the paused display
    ''' </summary>
    ''' <value>The new Delay value</value>
    ''' <returns>The current Delay value</returns>
    ''' <remarks>A value of 0 means no delay</remarks>
    Public Property Delay As Integer
        Get
            Return pfvDelay
        End Get
        Set(value As Integer)
            If value >= MIN_SLEEP And value <= MAX_SLEEP Then
                pfvDelay = value
            End If
        End Set
    End Property

    ''' <summary>
    ''' Did the calculator engine indicate that the menu needs to be updated?
    ''' </summary>
    ''' <value>The new menu state</value>
    ''' <returns>The current menu state</returns>
    ''' <remarks></remarks>
    Public Property MenuNeedsUpdating As Boolean
        Get
            Return pfvMenuNeedsUpdating
        End Get
        Set(value As Boolean)
            pfvMenuNeedsUpdating = value
        End Set
    End Property

    ''' <summary>
    ''' Did the calculator engine ask for a beep?
    ''' </summary>
    ''' <value>The new Beep state</value>
    ''' <returns>The current Beep state</returns>
    ''' <remarks></remarks>
    Public Property Beep As Boolean
        Get
            Return pfvBeep
        End Get
        Set(value As Boolean)
            pfvBeep = value
        End Set
    End Property

    ''' <summary>
    ''' Did the calculator engine indicate that a program should start?
    ''' </summary>
    ''' <value>The new Start state</value>
    ''' <returns>The current Start state</returns>
    ''' <remarks></remarks>
    Public Property Start As StartType
        Get
            Return pfvStart
        End Get
        Set(value As StartType)
            pfvStart = value
        End Set
    End Property
End Class
