﻿Public Class DynamicText
    Inherits TextBox

    Private Const MIN_SIZE As Integer = 5
    Private Const MAX_SIZE As Integer = 100
    Private pfvMinFontSize As Integer    ' minimum font size
    Private pfvMaxFontSize As Integer    ' maximum font size
    Private pfvAutoScale As Boolean      ' enabled the autoscaling feature
    Private widthLimitPixels As Integer

    Private calcMax As Single

    ' the calculated max font based on height
    Public Sub New()
        MyBase.New

        ' wire our event handler
        AddHandler Me.TextChanged, AddressOf DynamicText_TextChanged

        ' let's start with some defaults
        Me.pfvMinFontSize = MIN_SIZE
        Me.pfvMaxFontSize = MAX_SIZE
        Me.pfvAutoScale = True
    End Sub

    Private Sub DynamicText_TextChanged(ByVal sender As Object, ByVal e As EventArgs)
        ' let's check out the container first...
        Me.widthLimitPixels = Me.Width - Me.Margin.Right - Me.Margin.Left
        Me.calcMax = (Me.Height - Me.Margin.Top - Me.Margin.Bottom) / 1.5!

        If (Me.pfvAutoScale AndAlso Not String.IsNullOrEmpty(Me.Text)) Then
            Dim g As Graphics = Me.CreateGraphics
            Dim flags As TextFormatFlags = (TextFormatFlags.SingleLine And TextFormatFlags.TextBoxControl)
            Dim Proposed As Size = New Size(Integer.MaxValue, Integer.MaxValue)
            Dim fontsize As Single = Me.pfvMinFontSize
            Dim f As Font = New Font(Me.Font.FontFamily, fontsize)
            Dim widthPixels As Integer = TextRenderer.MeasureText(g, Me.Text, f, Proposed, flags).Width

            ' Increase font size to match.
            While ((widthPixels < Me.widthLimitPixels) AndAlso ((fontsize <= Me.pfvMaxFontSize) AndAlso (fontsize <= Me.calcMax)))
                fontsize = (fontsize + 1)
                f = New Font(Me.Font.FontFamily, fontsize)
                widthPixels = TextRenderer.MeasureText(g, Me.Text, f, Proposed, flags).Width
            End While

            fontsize -= 1.25!

            Me.Font = New Font(Me.Font.FontFamily, fontsize)
            g.Dispose()
        End If

    End Sub

    Public Property MinFontSize As Integer
        Get
            Return Me.pfvMinFontSize
        End Get
        Set
            If (Value >= MIN_SIZE) Then
                Me.pfvMinFontSize = Value
            End If

        End Set
    End Property

    Public Property MaxFontSize As Integer
        Get
            Return Me.pfvMaxFontSize
        End Get
        Set
            If (Value <= MAX_SIZE) Then
                Me.pfvMaxFontSize = Value
            End If

        End Set
    End Property

    Public Property AutoScale As Boolean
        Get
            Return Me.pfvAutoScale
        End Get
        Set
            Me.pfvAutoScale = Value
        End Set
    End Property
End Class
