﻿''' <summary>
''' A Graphical Button class
''' </summary>
''' <remarks>This has been highly customized just for this project</remarks>
Public Class GButton
    Inherits Button
    Private pfvImageUp As Bitmap
    Private pfvImageDown As Bitmap
    Private pfvImageHover As Bitmap
    Private pfvX As Integer
    Private pfvY As Integer
    Private pfvKeyCode As Byte

    ''' <summary>
    ''' Default constructor
    ''' </summary>
    ''' <remarks></remarks>
    Public Sub New()
        ' This call is required by the Windows Form Designer.
        InitializeComponent()

        ' Set some defaults...
        Me.FlatStyle = Windows.Forms.FlatStyle.Flat
        Me.FlatAppearance.BorderSize = 0
        Me.BackgroundImageLayout = ImageLayout.Stretch
        Me.Width = 37
        Me.Height = 33
    End Sub

    ''' <summary>
    ''' The image for the default button face
    ''' </summary>
    ''' <value>Set the default image</value>
    ''' <returns>Return the default image</returns>
    ''' <remarks></remarks>
    Public Property ImageUp As Bitmap
        Get
            Return pfvImageUp
        End Get
        Set(value As Bitmap)
            pfvImageUp = value
            ' also set the background
            Me.BackgroundImage = pfvImageUp
        End Set
    End Property

    ''' <summary>
    ''' The image used for the button face while it is pressed
    ''' </summary>
    ''' <value>Set the down image</value>
    ''' <returns>Return the down image</returns>
    ''' <remarks>Required</remarks>
    Public Property ImageDown As Bitmap
        Get
            Return pfvImageDown
        End Get
        Set(value As Bitmap)
            pfvImageDown = value
        End Set
    End Property

    ''' <summary>
    ''' The image used for the button face while hovering
    ''' </summary>
    ''' <value>Set the hover image</value>
    ''' <returns>Return the hover image</returns>
    ''' <remarks>Optional</remarks>
    Public Property ImageHover As Bitmap
        Get
            Return pfvImageHover
        End Get
        Set(value As Bitmap)
            pfvImageHover = value
        End Set
    End Property

    ''' <summary>
    ''' the X location in the "Button Grid"
    ''' </summary>
    ''' <value>Set the X value</value>
    ''' <returns>Return the X value</returns>
    ''' <remarks></remarks>
    Public Property X As Integer
        Get
            Return pfvX
        End Get
        Set(value As Integer)
            pfvX = value
        End Set
    End Property

    ''' <summary>
    ''' the Y location in the "Button Grid"
    ''' </summary>
    ''' <value>Set the Y value</value>
    ''' <returns>Return the Y value</returns>
    ''' <remarks></remarks>
    Public Property Y As Integer
        Get
            Return pfvY
        End Get
        Set(value As Integer)
            pfvY = value
        End Set
    End Property

    ''' <summary>
    ''' The numeric code for this key
    ''' </summary>
    ''' <value>Set the keycode</value>
    ''' <returns>Return the keycode</returns>
    ''' <remarks>See Calculator class for a description</remarks>
    Public Property KeyCode As Byte
        Get
            Return pfvKeyCode
        End Get
        Set(value As Byte)
            pfvKeyCode = value
        End Set
    End Property

    ''' <summary>
    ''' Change the background image when the button is pressed
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>Required</remarks>
    Private Sub GButton_MouseDown(sender As System.Object, e As System.Windows.Forms.MouseEventArgs) Handles MyBase.MouseDown
        Me.BackgroundImage = pfvImageDown
    End Sub

    ''' <summary>
    ''' Change the background image when the button is released
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>Required</remarks>
    Private Sub GButton_MouseUp(sender As System.Object, e As System.Windows.Forms.MouseEventArgs) Handles MyBase.MouseUp
        If pfvImageHover Is Nothing Then
            Me.BackgroundImage = pfvImageUp
        Else
            Me.BackgroundImage = pfvImageHover
        End If
    End Sub

    ''' <summary>
    ''' Change the background image when the mouse enters the button
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>Optional: Only if ImageHover is used</remarks>
    Private Sub GButton_MouseEnter(sender As System.Object, e As System.EventArgs) Handles MyBase.MouseEnter
        If pfvImageHover IsNot Nothing Then
            Me.BackgroundImage = pfvImageHover
        End If
    End Sub

    ''' <summary>
    ''' Change the background image when the mouse leaves the button
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>Optional: Only if ImageHover is used</remarks>
    Private Sub GButton_MouseLeave(sender As System.Object, e As System.EventArgs) Handles MyBase.MouseLeave
        If pfvImageHover IsNot Nothing Then
            Me.BackgroundImage = pfvImageUp
        End If
    End Sub
End Class
