﻿''' <summary>
''' A storage register
''' </summary>
''' <remarks>A container class for both a Double and BigInteger values</remarks>
Public Class Register

    Private pfvFVal As Double
    Private pfvBiVal As BigInt

    ''' <summary>
    ''' Default constructor
    ''' </summary>
    ''' <remarks>Default word size of 32</remarks>
    Public Sub New()
        pfvFVal = 0
        pfvBiVal = New BigInt(32, BigInt.ArithMode.TwosComp)
    End Sub

    ''' <summary>
    ''' Create a new Register given the Big Integer size and Arithmetic Mode
    ''' </summary>
    ''' <param name="size">The size in bits of the Big Integer</param>
    ''' <param name="mode">The arithmetic mode for the Big Integer</param>
    ''' <remarks></remarks>
    Public Sub New(size As Integer, mode As BigInt.ArithMode)
        pfvFVal = 0
        pfvBiVal = New BigInt(size, CType(mode, BigInt.ArithMode))
    End Sub

    ''' <summary>
    ''' The float value inside the register container
    ''' </summary>
    ''' <value>The new float value</value>
    ''' <returns>The existing float value</returns>
    ''' <remarks>Is actually a double</remarks>
    Public Property FVal As Double
        Get
            Return pfvFVal
        End Get
        Set(value As Double)
            pfvFVal = value
        End Set
    End Property

    ''' <summary>
    ''' The Big Integer value inside the Register
    ''' </summary>
    ''' <value>The new Big Integer value</value>
    ''' <returns>The existing Big Integer value</returns>
    ''' <remarks></remarks>
    Public Property BiVal As BigInt
        Get
            Return pfvBiVal
        End Get
        Set(value As BigInt)
            pfvBiVal = value
        End Set
    End Property

    ''' <summary>
    ''' Make a "deep" copy of a register
    ''' </summary>
    ''' <returns>A new Register instance with all data copied</returns>
    ''' <remarks></remarks>
    Public Function Copy() As Register
        Dim temp As New Register
        temp.pfvFVal = pfvFVal
        temp.pfvBiVal = New BigInt(pfvBiVal, pfvBiVal.WordSize, pfvBiVal.BIArithMode)
        Return temp
    End Function

End Class
